"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BridgeAccounts = exports.BridgeAccountNames = void 0;
var BridgeAccountNames;
(function (BridgeAccountNames) {
    BridgeAccountNames["algorand_asaOwner"] = "algorand_asaOwner";
    BridgeAccountNames["algorand_algoOwner"] = "algorand_algoOwner";
    BridgeAccountNames["algorand_bridgeOwner"] = "algorand_bridgeOwner";
    BridgeAccountNames["algorand_feeReceiver"] = "algorand_feeReceiver";
    BridgeAccountNames["algorand_multisig1"] = "algorand_multisig1";
    BridgeAccountNames["algorand_multisig2"] = "algorand_multisig2";
    BridgeAccountNames["algorand__bridge"] = "algorand__bridge";
    BridgeAccountNames["algorand_asaVault"] = "algorand_asaVault";
    BridgeAccountNames["algorand_algoVault"] = "algorand_algoVault";
})(BridgeAccountNames = exports.BridgeAccountNames || (exports.BridgeAccountNames = {}));
class BridgeAccounts {
    //Load/Save Config
    static loadConfig(path) {
        BridgeAccounts.config = require(path);
    }
    static saveConfig(path) {
        let writeValue = JSON.stringify(BridgeAccounts.config, (key, value) => typeof value === 'bigint' ? value.toString() : value, 2);
        let fs = require('fs');
        fs.writeFileSync(path, writeValue, function (err) {
            if (err) {
                console.log(err);
            }
        });
    }
    //Get Account Info
    static getAddress(name) {
        let network = name.split("_")[0];
        let accountName = name.split("_")[1];
        let info = BridgeAccounts.getAccountInfo(network, accountName);
        if (info === undefined) {
            //Check msig
            let msigInfo = BridgeAccounts.getMSigInfo(network, accountName);
            if (msigInfo === undefined) {
                throw new Error("Account not found: " + name);
            }
            else {
                return msigInfo.address;
            }
        }
        else {
            return info.address;
        }
    }
    static getAccountInfo(network, name) {
        console.log(`matching: ${name.toLowerCase()} ${network.toLowerCase()}`);
        let accounts = BridgeAccounts.config.bridge_accounts;
        accounts.push(...BridgeAccounts.config.local_accounts);
        for (let i = 0; i < accounts.length; i++) {
            let info = accounts[i];
            if (info.network.toLowerCase() === network.toLowerCase() &&
                info.name.toLowerCase() === name.toLowerCase())
                return info;
        }
        return undefined;
    }
    static getMSigInfo(network, name) {
        console.log(`matching: ${name.toLowerCase()} ${network.toLowerCase()}`);
        let accounts = BridgeAccounts.config.bridge_msigs;
        accounts.push(...BridgeAccounts.config.local_msigs);
        for (let i = 0; i < accounts.length; i++) {
            let info = accounts[i];
            if (info.network.toLowerCase() === network.toLowerCase() &&
                info.name.toLowerCase() === name.toLowerCase())
                return info;
        }
        return undefined;
    }
}
exports.BridgeAccounts = BridgeAccounts;
BridgeAccounts.config = {
    bridge_accounts: [],
    local_accounts: [],
    bridge_msigs: [],
    local_msigs: [],
    loaded: false
};
