"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BridgeTokens = exports.initToken = exports.TokenParams = void 0;
var TokenParams;
(function (TokenParams) {
    TokenParams[TokenParams["none"] = 0] = "none";
    TokenParams[TokenParams["name"] = 2] = "name";
    TokenParams[TokenParams["symbol"] = 4] = "symbol";
    TokenParams[TokenParams["decimals"] = 8] = "decimals";
    TokenParams[TokenParams["total_supply"] = 16] = "total_supply";
    TokenParams[TokenParams["min_transfer"] = 32] = "min_transfer";
    TokenParams[TokenParams["max_transfer"] = 64] = "max_transfer";
    TokenParams[TokenParams["fee_divisor"] = 128] = "fee_divisor";
    TokenParams[TokenParams["all"] = 254] = "all";
})(TokenParams = exports.TokenParams || (exports.TokenParams = {}));
function initToken(options) {
    const defaults = {
        network: "",
        name: "",
        symbol: "",
        type: "",
        asset_id: undefined,
        bridge_vault_id: undefined,
        decimals: 0,
        min_transfer: undefined,
        max_transfer: undefined,
        fee_divisor: undefined,
        total_supply: BigInt(0),
        loaded: false
    };
    return Object.assign(Object.assign({}, defaults), options);
}
exports.initToken = initToken;
class BridgeTokens {
    //Load/Save Config
    static loadConfig(path) {
        BridgeTokens.config = require(path);
    }
    static saveConfig(path) {
        let writeValue = JSON.stringify(BridgeTokens.config, (key, value) => typeof value === 'bigint' ? value.toString() : value, 2);
        let fs = require('fs');
        fs.writeFileSync(path, writeValue, function (err) {
            if (err) {
                console.log(err);
            }
        });
    }
    //Get Token Info
    static getTokenInfo(network, symbol) {
        console.log(`matching: ${symbol.toLowerCase()} ${network.toLowerCase()}`);
        let tokens = BridgeTokens.config.assets_info;
        for (let i = 0; i < tokens.length; i++) {
            let token = tokens[i];
            if (token.network.toLowerCase() === network.toLowerCase() &&
                token.symbol.toLowerCase() === symbol.toLowerCase())
                return token;
        }
        return undefined;
    }
    static loadFromCli(requiredParams) {
        let token = initToken();
        try {
            //parse params
            var argv = require('minimist')(process.argv.slice(2));
            token.name = argv.name;
            token.decimals = argv.d;
            token.symbol = argv.s;
            if (argv.network)
                token.network = argv.network.toLowerCase();
            token.min_transfer = argv.min;
            token.max_transfer = argv.max;
            token.fee_divisor = argv.fee;
            let totalSupply = argv.t;
            token.total_supply = (!totalSupply ? BigInt(0) : BigInt(totalSupply));
            //ensure params are set
            if (requiredParams) {
                if ((requiredParams & TokenParams.name) === TokenParams.name) {
                    if (!token.name && token.name === undefined)
                        throw new Error("Token Name is required");
                }
                if ((requiredParams & TokenParams.symbol) === TokenParams.symbol) {
                    if (!token.symbol && token.symbol === undefined)
                        throw new Error("Asset Symbol is required");
                }
                if ((requiredParams & TokenParams.decimals) === TokenParams.decimals) {
                    if (!token.decimals && token.decimals === undefined)
                        throw new Error("Decimals is required");
                }
                if ((requiredParams & TokenParams.total_supply) === TokenParams.total_supply) {
                    if (!token.total_supply && token.total_supply === undefined)
                        throw new Error("Total Supply is required");
                }
                if ((requiredParams & TokenParams.min_transfer) === TokenParams.min_transfer) {
                    if (!token.min_transfer) {
                        throw new Error('Minimum Transfer not specified');
                    }
                    else if (token.min_transfer <= 0) {
                        throw new Error('Minimum Transfer must be greater than 0');
                    }
                }
                if ((requiredParams & TokenParams.max_transfer) === TokenParams.max_transfer) {
                    if (!token.max_transfer) {
                        throw new Error('Maximum Transfer not specified');
                    }
                    else if (token.max_transfer <= 0) {
                        throw new Error('Maximum Transfer must be greater than 0');
                    }
                    else if (!token.min_transfer) {
                        throw new Error('Minimum Transfer not specified');
                    }
                    else if (token.max_transfer <= token.min_transfer) {
                        throw new Error('Maximum Transfer must be greater than Minimum Transfer');
                    }
                }
                if ((requiredParams & TokenParams.fee_divisor) === TokenParams.fee_divisor) {
                    if (!token.fee_divisor) {
                        throw new Error('Fee Divisor not specified');
                    }
                    else if (token.fee_divisor < 1) {
                        throw new Error('Fee Divisor must be greater than 1');
                    }
                }
            }
            //Passed All Checks:
            token.loaded = true;
        }
        catch (error) {
            console.log(error);
        }
        return token;
    }
}
exports.BridgeTokens = BridgeTokens;
BridgeTokens.config = {
    approval_app: 0,
    assets_info: [],
    loaded: false
};
